// The package containing our stubs.
import HelloWorld.*;

// HelloServer will use the naming service.
import org.omg.CosNaming.*;

// The package containing special exceptions thrown by the name service.
import org.omg.CosNaming.NamingContextPackage.*;

// All CORBA applications need these classes.
import org.omg.CORBA.*;
import org.omg.PortableServer.*;
import org.omg.PortableServer.POA;

public class HelloServer 
{
  public static void main(String args[])
  {
    try{
    
      // Create and initialize the ORB
      ORB orb = ORB.init(args, null);
      
      POA rootpoa=POAHelper.narrow(orb.resolve_initial_references("RootPOA"));
      rootpoa.the_POAManager().activate();

      // Create and activate a new POA with our policy
	  Policy[] policies = new Policy[3];
	  policies[0] = rootpoa.create_lifespan_policy(LifespanPolicyValue.TRANSIENT);
	  policies[1] = rootpoa.create_id_assignment_policy(IdAssignmentPolicyValue.USER_ID);
	  policies[2] = rootpoa.create_request_processing_policy(RequestProcessingPolicyValue.USE_DEFAULT_SERVANT);
	  POA poa = rootpoa.create_POA("my_poa", null, policies);
      poa.the_POAManager().activate();
      	
      // Create the factory object
      HelloFactoryImpl helloRef = new HelloFactoryImpl();
      poa.activate_object_with_id("Factory".getBytes(), helloRef);
	  org.omg.CORBA.Object ref = poa.servant_to_reference(helloRef);
      HelloFactory href = HelloFactoryHelper.narrow(ref);
      
      // Create and register the default servant
      HelloImpl hello = new HelloImpl();
	  poa.set_servant(hello);

	  // Register the factory object
      org.omg.CORBA.Object objRef = orb.resolve_initial_references("NameService");
      NamingContextExt ncRef = NamingContextExtHelper.narrow(objRef);
      ncRef.rebind(ncRef.to_name("HelloWorld"), href);
         
	  System.out.println("HelloServer is running...");
	  
	  orb.run();
      
    } catch(Exception e) {
        System.err.println("ERROR: " + e);
        e.printStackTrace(System.out);
      }  
  }
}

